@@ -73,7 +73,7 @@ class TransformType(click.ParamType):
     def convert(self, value, param, ctx):
         name = ''
         try:
-            name, args = split_args_from_name_or_path(value)
+            name, args = split_args_from_name_or_path(value.replace(' ', ''))
         except ValueError:
             exc = f'Invalid {name} transformer configuration. ' \
                   f'Parameters should be provided in format name=value, delimited by :'
@@ -140,12 +140,28 @@ def load_toml_file(path: str) -> Dict[str, Any]:
 
 
 def read_pyproject_config(path: str) -> Dict[str, Any]:
-    click.echo(f'Reading {path}')
     config = load_toml_file(path)
     config = config.get("tool", {}).get("robotidy", {})
     return {k.replace('--', '').replace('-', '_'): v for k, v in config.items()}
 
 
+def parse_opt(opt):
+    while opt and opt[0] == '-':
+        opt = opt[1:]
+    return opt.replace('-', '_')
+
+
+def validate_config_options(params, config):
+    if params is None:
+        return
+    allowed = {parse_opt(opt) for param in params for opt in param.opts}
+    for conf in config:
+        if conf not in allowed:
+            rec_finder = RecommendationFinder()
+            similar = rec_finder.find(conf, list(allowed))
+            raise click.NoSuchOption(conf, possibilities=similar)
+
+
 def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]) -> Optional[str]:
     # if --config was not used, try to find pyproject.toml or robotidy.toml file
     if value:
@@ -161,7 +177,7 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
         k: str(v) if not isinstance(v, (list, dict)) else v
         for k, v in config.items()
     }
-
+    validate_config_options(ctx.command.params, config)
     default_map: Dict[str, Any] = {}
     if ctx.default_map:
         default_map.update(ctx.default_map)
@@ -190,7 +206,7 @@ def print_description(name: str):
 def print_transformers_list():
     transformers = load_transformers(None, {}, allow_disabled=True)
     click.echo('To see detailed docs run --desc <transformer_name> or --desc all. '
-               'Transformers with (disabled) tag \nare executed only when selected explictly with --transform. '
+               'Transformers with (disabled) tag \nare executed only when selected explicitly with --transform. '
                'Available transformers:\n')
     transformer_names = []
     for transformer in transformers:
